@@ -1,4 +1,4 @@
-__version__ = "0.1"
+__version__ = "1.0"
 __author__ = "Pablo Velasco"
 __author_email__ = "pablo.velasco@nyu.edu"
 __url__ = "https://github.com/cbinyu/mriqc_comparison"
@@ -22,7 +22,7 @@ PYTHON_REQUIRES = ">=3.6"
 REQUIRES = [
     'pandas >= 0.25.0',
     'numpy >= 1.17.1',
-    'mriqc >= 0.15',
+    'mriqc >= 0.13.0',
 ]
 
 TESTS_REQUIRES = [
